Crate coalesced_intervals
coalesced_
intervals
0.1.6
All Items
Crate Items
Structs
Crate
coalesced_
intervals
Structs

Coalesced
Intervals
This is a conceptually simple data structure designed for the case where you have intervals that you’d like to coalesce into maximal contiguous runs.